@@ -3,21 +3,21 @@ import json
 import grpc
 import os
 from typing import Optional
-import keyvaluestore_pb2 as herd_serv
-import keyvaluestore_pb2_grpc as herd_grpc
+from . import keyvaluestore_pb2 as herd_serv
+from . import keyvaluestore_pb2_grpc as herd_grpc
 
 class HerdClient:
     """Client for the Herd gRPC service."""
     
     # Initialize the client with host and port
-    def __init__(self, host: str = 'localhost', port: int = 50051):
+    def __init__(self, host: str = 'localhost', port: int = 50051, cert_path: str = ""):
         """Initialize the client with host and port."""
         # Load the certificates
-        with open(os.path.join('../../certs', 'ca.crt'), 'rb') as f:
+        with open(os.path.join(cert_path, 'ca.crt'), 'rb') as f:
             root_certificates = f.read()
-        with open(os.path.join('../../certs', 'server.crt'), 'rb') as f:
+        with open(os.path.join(cert_path, 'server.crt'), 'rb') as f:
             certificate_chain = f.read()
-        with open(os.path.join('../../certs', 'server.key'), 'rb') as f:
+        with open(os.path.join(cert_path, 'server.key'), 'rb') as f:
             private_key = f.read()
 
         # Create the SSL credentials
@@ -31,11 +31,11 @@ class HerdClient:
         self.stub = herd_grpc.KeyValueServiceStub(self.channel)
         
         # Check if the channel is ready
-        # try:
-        #     grpc.channel_ready_future(self.channel).result(timeout=5)
-        #     print(f"Connected to Herd gRPC server on {host}:{port}.")
-        # except grpc.FutureTimeoutError:
-        #     print(f"Error connecting to Herd gRPC server on {host}:{port}.")
+        try:
+            grpc.channel_ready_future(self.channel).result(timeout=5)
+            print(f"Connected to Herd gRPC server on {host}:{port}.")
+        except grpc.FutureTimeoutError:
+            print(f"Error connecting to Herd gRPC server on {host}:{port}.")
     
     # Set a value in the key-value store.
     # Returns True if the value was converted to json -> bytes, and set successfully.
